# $Id: Request.pm,v 1.3 2007/08/14 15:45:51 ajk Exp $

package # hide from PAUSE
    Data::Passphrase::Request;

1;
__END__

=begin WSDL

_ATTR passphrase $string passphrase to be validated
_ATTR username   $string username for use in validation

=end WSDL
